@@ -22,6 +22,7 @@ from .remote_connection import RemoteConnection
 from .errorhandler import ErrorHandler
 from .switch_to import SwitchTo
 from .mobile import Mobile
+from .file_detector import FileDetector, LocalFileDetector
 from selenium.common.exceptions import WebDriverException
 from selenium.common.exceptions import InvalidSelectorException
 from selenium.webdriver.common.by import By
@@ -73,6 +74,7 @@ class WebDriver(object):
         self.start_session(desired_capabilities, browser_profile)
         self._switch_to = SwitchTo(self)
         self._mobile = Mobile(self)
+        self.file_detector = LocalFileDetector()
 
     @property
     def mobile(self):
@@ -161,10 +163,11 @@ class WebDriver(object):
         :Returns:
           The command's JSON response loaded into a dictionary object.
         """
-        if not params:
-            params = {'sessionId': self.session_id}
-        elif 'sessionId' not in params:
-            params['sessionId'] = self.session_id
+        if self.session_id is not None:
+            if not params:
+                params = {'sessionId': self.session_id}
+            elif 'sessionId' not in params:
+                params['sessionId'] = self.session_id
 
         params = self._wrap_value(params)
         response = self.command_executor.execute(driver_command, params)
@@ -771,6 +774,29 @@ class WebDriver(object):
         return self.execute(Command.GET_WINDOW_POSITION,
             {'windowHandle': windowHandle})['value']
 
+    @property
+    def file_detector(self):
+        return self._file_detector
+
+    @file_detector.setter
+    def file_detector(self, detector):
+        """
+        Set the file detector to be used when sending keyboard input.
+        By default, this is set to a file detector that does nothing.
+
+        see FileDetector
+        see LocalFileDetector
+        see UselessFileDetector
+
+        :Args:
+         - detector: The detector to use. Must not be None.
+        """
+        if detector == None:
+            raise WebDriverException("You may not set a file detector that is null")
+        if not isinstance(detector, FileDetector):
+            raise WebDriverException("Detector has to be instance of FileDetector")
+        self._file_detector = detector;
+
     @property
     def orientation(self):
         """
@@ -798,10 +824,6 @@ class WebDriver(object):
         else:
             raise WebDriverException("You can only set the orientation to 'LANDSCAPE' and 'PORTRAIT'")
 
-    def is_online(self):
-        """ Returns a boolean if the browser is online or offline"""
-        return self.execute(Command.IS_BROWSER_ONLINE)['value']
-
     @property
     def application_cache(self):
         """ Returns a ApplicationCache Object to interact with the browser app cache"""
