@@ -1,4 +1,4 @@
-# Copyright 2008-2013 Software freedom conservancy
+# Copyright 2008-2014 Software freedom conservancy
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
-"""WebElement implementation."""
 import hashlib
 import os
 import zipfile
@@ -23,13 +21,13 @@ except ImportError:  # 3+
     from io import BytesIO as IOStream
 import base64
 
-
 from .command import Command
 from selenium.common.exceptions import WebDriverException
 from selenium.common.exceptions import InvalidSelectorException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.keys import Keys
 
+
 try:
     str = basestring
 except NameError:
@@ -37,22 +35,29 @@ except NameError:
 
 
 class WebElement(object):
-    """Represents an HTML element.
+    """Represents a DOM element.
+
+    Generally, all interesting operations that interact with a document will be
+    performed through this interface.
+
+    All method calls will do a freshness check to ensure that the element
+    reference is still valid.  This essentially determines whether or not the
+    element is still attached to the DOM.  If this test fails, then an
+    ``StaleElementReferenceException`` is thrown, and all future calls to this
+    instance will fail."""
 
-    Generally, all interesting operations to do with interacting with a page
-    will be performed through this interface."""
     def __init__(self, parent, id_):
         self._parent = parent
         self._id = id_
 
     @property
     def tag_name(self):
-        """Gets this element's tagName property."""
+        """This element's ``tagName`` property."""
         return self._execute(Command.GET_ELEMENT_TAG_NAME)['value']
 
     @property
     def text(self):
-        """Gets the text of the element."""
+        """The text of the element."""
         return self._execute(Command.GET_ELEMENT_TEXT)['value']
 
     def click(self):
@@ -68,14 +73,24 @@ class WebElement(object):
         self._execute(Command.CLEAR_ELEMENT)
 
     def get_attribute(self, name):
-        """Gets the attribute value.
+        """Gets the given attribute or property of the element.
+
+        This method will first try to return the value of a property with the
+        given name. If a property with that name doesn't exist, it returns the
+        value of the attribute with the same name. If there's no attribute with
+        that name, ``None`` is returned.
+
+        Values which are considered truthy, that is equals "true" or "false",
+        are returned as booleans.  All other non-``None`` values are returned
+        as strings.  For attributes or properties which do not exist, ``None``
+        is returned.
 
         :Args:
-            - name - name of the attribute property to retieve.
+            - name - Name of the attribute/property to retrieve.
 
         Example::
 
-            # Check if the 'active' css class is applied to an element.
+            # Check if the "active" CSS class is applied to an element.
             is_active = "active" in target_element.get_attribute("class")
 
         """
@@ -87,22 +102,21 @@ class WebElement(object):
             attributeValue = resp['value']
             if name != 'value' and attributeValue.lower() in ('true', 'false'):
                 attributeValue = attributeValue.lower()
-
         return attributeValue
 
     def is_selected(self):
-        """Whether the element is selected.
+        """Returns whether the element is selected.
 
         Can be used to check if a checkbox or radio button is selected.
         """
         return self._execute(Command.IS_ELEMENT_SELECTED)['value']
 
     def is_enabled(self):
-        """Whether the element is enabled."""
+        """Returns whether the element is enabled."""
         return self._execute(Command.IS_ELEMENT_ENABLED)['value']
 
     def find_element_by_id(self, id_):
-        """Finds element within the child elements of this element.
+        """Finds element within this element's children by ID.
 
         :Args:
             - id_ - ID of child element to locate.
@@ -110,8 +124,7 @@ class WebElement(object):
         return self.find_element(by=By.ID, value=id_)
 
     def find_elements_by_id(self, id_):
-        """Finds a list of elements within the children of this element
-        with the matching ID.
+        """Finds a list of elements within this element's children by ID.
 
         :Args:
             - id_ - Id of child element to find.
@@ -119,14 +132,15 @@ class WebElement(object):
         return self.find_elements(by=By.ID, value=id_)
 
     def find_element_by_name(self, name):
-        """Find element with in this element's children by name.
+        """Finds element within this element's children by name.
+
         :Args:
             - name - name property of the element to find.
         """
         return self.find_element(by=By.NAME, value=name)
 
     def find_elements_by_name(self, name):
-        """Finds a list of elements with in this element's children by name.
+        """Finds a list of elements within this element's children by name.
 
         :Args:
             - name - name property to search for.
@@ -134,7 +148,7 @@ class WebElement(object):
         return self.find_elements(by=By.NAME, value=name)
 
     def find_element_by_link_text(self, link_text):
-        """Finds element with in this element's children by visible link text.
+        """Finds element within this element's children by visible link text.
 
         :Args:
             - link_text - Link text string to search for.
@@ -142,7 +156,7 @@ class WebElement(object):
         return self.find_element(by=By.LINK_TEXT, value=link_text)
 
     def find_elements_by_link_text(self, link_text):
-        """Finds a list of elements with in this element's children by visible link text.
+        """Finds a list of elements within this element's children by visible link text.
 
         :Args:
             - link_text - Link text string to search for.
@@ -150,7 +164,7 @@ class WebElement(object):
         return self.find_elements(by=By.LINK_TEXT, value=link_text)
 
     def find_element_by_partial_link_text(self, link_text):
-        """Finds element with in this element's children by parial visible link text.
+        """Finds element within this element's children by partially visible link text.
 
         :Args:
             - link_text - Link text string to search for.
@@ -158,7 +172,7 @@ class WebElement(object):
         return self.find_element(by=By.PARTIAL_LINK_TEXT, value=link_text)
 
     def find_elements_by_partial_link_text(self, link_text):
-        """Finds a list of elements with in this element's children by link text.
+        """Finds a list of elements within this element's children by link text.
 
         :Args:
             - link_text - Link text string to search for.
@@ -166,7 +180,7 @@ class WebElement(object):
         return self.find_elements(by=By.PARTIAL_LINK_TEXT, value=link_text)
 
     def find_element_by_tag_name(self, name):
-        """Finds element with in this element's children by tag name.
+        """Finds element within this element's children by tag name.
 
         :Args:
             - name - name of html tag (eg: h1, a, span)
@@ -174,7 +188,7 @@ class WebElement(object):
         return self.find_element(by=By.TAG_NAME, value=name)
 
     def find_elements_by_tag_name(self, name):
-        """Finds a list of elements with in this element's children by tag name.
+        """Finds a list of elements within this element's children by tag name.
 
         :Args:
             - name - name of html tag (eg: h1, a, span)
@@ -189,53 +203,63 @@ class WebElement(object):
 
         Note: The base path will be relative to this element's location.
 
-        This will select the first link under this element.::
+        This will select the first link under this element.
+
+        ::
 
             myelement.find_elements_by_xpath(".//a")
 
         However, this will select the first link on the page.
 
+        ::
+
             myelement.find_elements_by_xpath("//a")
 
         """
         return self.find_element(by=By.XPATH, value=xpath)
 
     def find_elements_by_xpath(self, xpath):
-        """Finds elements within the elements by xpath.
+        """Finds elements within the element by xpath.
 
         :Args:
             - xpath - xpath locator string.
 
         Note: The base path will be relative to this element's location.
 
-        This will select all links under this element.::
+        This will select all links under this element.
+
+        ::
 
             myelement.find_elements_by_xpath(".//a")
 
         However, this will select all links in the page itself.
 
+        ::
+
             myelement.find_elements_by_xpath("//a")
+
         """
         return self.find_elements(by=By.XPATH, value=xpath)
 
     def find_element_by_class_name(self, name):
-        """Finds an element within this element's children by their class name.
+        """Finds element within this element's children by class name.
 
         :Args:
-            - name - class name to search on.
+            - name - class name to search for.
         """
         return self.find_element(by=By.CLASS_NAME, value=name)
 
+
     def find_elements_by_class_name(self, name):
-        """Finds a list of elements within children of this element by their class name.
+        """Finds a list of elements within this element's children by class name.
 
         :Args:
-            - name - class name to search on.
+            - name - class name to search for.
         """
         return self.find_elements(by=By.CLASS_NAME, value=name)
 
     def find_element_by_css_selector(self, css_selector):
-        """Find and return an element that's a child of this element by CSS selector.
+        """Finds element within this element's children by CSS selector.
 
         :Args:
             - css_selector - CSS selctor string, ex: 'a.nav#home'
@@ -243,8 +267,7 @@ class WebElement(object):
         return self.find_element(by=By.CSS_SELECTOR, value=css_selector)
 
     def find_elements_by_css_selector(self, css_selector):
-        """Find and return list of multiple elements within the children of this
-        element by CSS selector.
+        """Finds a list of elements within this element's children by CSS selector.
 
         :Args:
             - css_selector - CSS selctor string, ex: 'a.nav#home'
@@ -263,7 +286,9 @@ class WebElement(object):
             form_textfield = driver.find_element_by_name('username')
             form_textfield.send_keys("admin")
 
-        This can also be used to set file inputs.::
+        This can also be used to set file inputs.
+
+        ::
 
             file_input = driver.find_element_by_name('profilePic')
             file_input.send_keys("path/to/profilepic.gif")
@@ -275,7 +300,7 @@ class WebElement(object):
         # transfer file to another machine only if remote driver is used
         # the same behaviour as for java binding
         if self.parent._is_remote:
-            local_file = LocalFileDetector.is_local_file(*value)
+            local_file = self.parent.file_detector.is_local_file(*value)
             if local_file is not None:
                 value = self._upload(local_file)
 
@@ -294,22 +319,24 @@ class WebElement(object):
 
     # RenderedWebElement Items
     def is_displayed(self):
-        """Whether the element would be visible to a user
-        """
+        """Whether the element is visible to a user."""
         return self._execute(Command.IS_ELEMENT_DISPLAYED)['value']
 
     @property
     def location_once_scrolled_into_view(self):
-        """CONSIDERED LIABLE TO CHANGE WITHOUT WARNING. Use this to discover where on the screen an
-        element is so that we can click it. This method should cause the element to be scrolled
-        into view.
+        """THIS PROPERTY MAY CHANGE WITHOUT WARNING. Use this to discover
+        where on the screen an element is so that we can click it. This method
+        should cause the element to be scrolled into view.
 
-        Returns the top lefthand corner location on the screen, or None if the element is not visible"""
+        Returns the top lefthand corner location on the screen, or ``None`` if
+        the element is not visible.
+
+        """
         return self._execute(Command.GET_ELEMENT_LOCATION_ONCE_SCROLLED_INTO_VIEW)['value']
 
     @property
     def size(self):
-        """ Returns the size of the element """
+        """The size of the element."""
         size = self._execute(Command.GET_ELEMENT_SIZE)['value']
         new_size = {}
         new_size["height"] = size["height"]
@@ -317,29 +344,34 @@ class WebElement(object):
         return new_size
 
     def value_of_css_property(self, property_name):
-        """ Returns the value of a CSS property """
+        """The value of a CSS property."""
         return self._execute(Command.GET_ELEMENT_VALUE_OF_CSS_PROPERTY,
                         {'propertyName': property_name})['value']
 
     @property
     def location(self):
-        """ Returns the location of the element in the renderable canvas"""
+        """The location of the element in the renderable canvas."""
         old_loc = self._execute(Command.GET_ELEMENT_LOCATION)['value']
         new_loc = {"x": old_loc['x'],
                    "y": old_loc['y']}
         return new_loc
 
+    @property
+    def rect(self):
+        """A dictionary with the size and location of the element."""
+        return self._execute(Command.GET_ELEMENT_RECT)['value']
+
     @property
     def parent(self):
-        """ Returns parent element is available. """
+        """Internal reference to the WebDriver instance this element was found from."""
         return self._parent
 
     @property
     def id(self):
-        """ Returns internal id used by selenium.
+        """Internal ID used by selenium.
 
-        This is mainly for internal use.  Simple use cases such as checking if 2 webelements
-        refer to the same element, can be done using '=='::
+        This is mainly for internal use. Simple use cases such as checking if 2
+        webelements refer to the same element, can be done using ``==``::
 
             if element1 == element2:
                 print("These 2 are equal")
@@ -406,32 +438,3 @@ class WebElement(object):
                 return filename
             else:
                 raise e
-
-class LocalFileDetector(object):
-
-    @classmethod
-    def is_local_file(cls, *keys):
-        file_path = ''
-        typing = []
-        for val in keys:
-            if isinstance(val, Keys):
-                typing.append(val)
-            elif isinstance(val, int):
-                val = val.__str__()
-                for i in range(len(val)):
-                    typing.append(val[i])
-            else:
-                for i in range(len(val)):
-                    typing.append(val[i])
-        file_path = ''.join(typing)
-
-        if file_path is '':
-            return None
-
-        try:
-            if os.path.isfile(file_path):
-                return file_path
-        except:
-            pass
-        return None
-
